@@ -281,13 +281,7 @@ class BuildSystem(object):
     def add_standard_build_actions(cls, executor, context, variant, build_type,
                                    install, build_path, install_path=None):
         """Perform build actions common to every build system.
-
-        This includes:
-        - Setting a standard list on env-vars;
-        - Executing pre_build_commands(), if the package has one.
         """
-        from rez.utils.data_utils import RO_AttrDictWrapper
-
         # set env vars
         env_vars = cls.get_standard_vars(
             context=context,
@@ -301,6 +295,13 @@ class BuildSystem(object):
         for var, value in env_vars.items():
             executor.env[var] = value
 
+    @classmethod
+    def add_pre_build_commands(cls, executor, variant, build_type,
+                               install, build_path, install_path=None):
+        """Execute pre_build_commands if present.
+        """
+        from rez.utils.data_utils import RO_AttrDictWrapper
+
         # bind build-related values into a 'build' namespace
         build_ns = {
             "build_type": build_type.name,
